/*
Code by @Dimzcraft.
(c) Don't use any Code without permission
*/
import { EquipmentSlot, world, system } from '@minecraft/server';

const armorSlots = [EquipmentSlot.Head, EquipmentSlot.Chest, EquipmentSlot.Legs, EquipmentSlot.Feet];
const armorId = {
  'minecraft:leather_helmet': 10,
  'minecraft:leather_chestplate': 11,
  'minecraft:leather_leggings': 12,
  'minecraft:leather_boots': 13,
  'minecraft:chainmail_helmet': 20,
  'minecraft:chainmail_chestplate': 21,
  'minecraft:chainmail_leggings': 22,
  'minecraft:chainmail_boots': 23,
  'minecraft:iron_helmet': 30,
  'minecraft:iron_chestplate': 31,
  'minecraft:iron_leggings': 32,
  'minecraft:iron_boots': 33,
  'minecraft:golden_helmet': 40,
  'minecraft:golden_chestplate': 41,
  'minecraft:golden_leggings': 42,
  'minecraft:golden_boots': 43,
  'minecraft:diamond_helmet': 50,
  'minecraft:diamond_chestplate': 51,
  'minecraft:diamond_leggings': 52,
  'minecraft:diamond_boots': 53,
  'minecraft:netherite_helmet': 60,
  'minecraft:netherite_chestplate': 61,
  'minecraft:netherite_leggings': 62,
  'minecraft:netherite_boots': 63,
  'minecraft:elytra': 70,
  'minecraft:turtle_helmet': 71,
  'minecraft:carved_pumpkin': 72,
  'minecraft:skull': 73,
};

function DurabilityArmorViewer(player) {
  const equipment = player.getComponent('equippable');
  
  let title = '§d§m§z§d§a§v§r§fArmor: ';
  let subtitle = '§d§m§z§d§a§v§r§fDurability: ';

  for (const slot of armorSlots) {
    const item = equipment.getEquipment(slot);
    const itemId = item ? armorId[item.typeId] || '403' : '403';
    title += `${itemId}, `;
  
    if (item && item.hasComponent('durability')) {
      const maxDurability = item.getComponent('durability').maxDurability;
      const damage = item.getComponent('durability').damage;
      const durabilityPercent = Math.floor((maxDurability - damage) / maxDurability * 100);
      subtitle += `${durabilityPercent}, `;
      
    } else {
      subtitle += `404, `;
    }
  };
 
  title = title.slice(0, -2);
  subtitle = subtitle.slice(0, -2);
  
//  console.error(title);
//  console.error(subtitle);
  player.onScreenDisplay.setTitle(title, { stayDuration: 1, fadeInDuration: 0, fadeOutDuration: 0, subtitle });
};

// run code
world.afterEvents.entityHurt.subscribe(function (event) {
  if (event.hurtEntity.typeId == "minecraft:player") {
    DurabilityArmorViewer(event.hurtEntity);
  }
});

world.afterEvents.itemUse.subscribe((event) => {
  const { source: player, itemStack: item } = event
  if (item.getComponent("minecraft:durability")?.isValid()) {
    DurabilityArmorViewer(player);
  }
});

system.runInterval(() => {
  for (const player of world.getPlayers()) {
    DurabilityArmorViewer(player);
  }
}, 50);

